export declare enum WasmSources {
    prod = "https://cdnjs.cloudflare.com/ajax/libs/sql.js/1.6.1/sql-wasm.wasm",
    debug = "https://cdnjs.cloudflare.com/ajax/libs/sql.js/1.6.1/sql-wasm-debug.wasm",
    test = "node_modules/sql.js/dist/sql-wasm.wasm"
}
export declare type SqlValue = string | number | null | Uint8Array;
export interface QueryExecResult {
    columns: Array<string>;
    values: Array<Array<SqlValue>>;
}
export declare type BindParams = Array<SqlValue> | Record<string, SqlValue> | null;
export interface SqlLite {
    exec: (query: string, params?: BindParams) => Array<QueryExecResult>;
}
/**
 * Defines the Singleton holding the database instance.
 */
export interface DatabaseHolder {
    instance: SqlLite | null;
    setInstance: (bd: SqlLite) => void;
    getInstance: () => SqlLite | null;
    destroy: () => void;
}
export declare type SqlDataType = 'INTEGER' | 'INT' | 'TEXT';
export interface Schema {
    [tableName: string]: {
        fields: Record<string, SqlDataType>;
        values?: Array<Record<string, string | number>>;
    };
}
/**
 * Defines the Recorder type.
 * Each string in the Record is associated with a table.
 * Each weakRef item is connected to a 'reactive' function that must be fired
 * after an insert query.
 */
export declare type Recorder = Record<string, Array<WeakRef<(t: number) => void>>>;
