declare type SqlValue = string | number | null | Uint8Array;
interface QueryExecResult {
    columns: Array<string>;
    values: Array<Array<SqlValue>>;
}
declare type BindParams = Array<SqlValue> | Record<string, SqlValue> | null;
interface SqlLite {
    exec: (query: string, params?: BindParams) => Array<QueryExecResult>;
}
declare type SqlDataType = 'INTEGER' | 'INT' | 'TEXT';
interface Schema {
    [tableName: string]: {
        fields: Record<string, SqlDataType>;
        values?: Array<Record<string, string | number>>;
    };
}

/**
 * Create SQLite instance using sql.js, from the input 'path' to the wasm file,
 * and schema definition.
 *
 *
 * @param path      Path to the wasm file
 * @param schema    Schema definition to create the database
 * @return database or undefined
 */
declare const createSQL: (path: string, schema: Schema) => Promise<SqlLite | undefined>;

declare function useQuery(query: string, depths?: Array<string | number | boolean | undefined | null>): {
    result: QueryExecResult[] | undefined;
    writeQueryFn: (query: string) => void;
};

/**
 * Hook that provide write-only access to the database
 *
 */
declare function useInsert(): (query: string) => void;

/**
 * Hook that provide read-only access to the database
 *
 * @param query     Query to be executed
 * @param depths
 */
declare function useSelect(query: string, depths?: Array<string | number | boolean | undefined | null>): QueryExecResult[] | undefined;

export { createSQL as default, useInsert, useQuery, useSelect };
